Naive Bayes Classification
**************************

.. automodule:: ibmdbpy.learn.naive_bayes

Initiate model
==============

.. currentmodule:: ibmdbpy.learn.naive_bayes
.. highlight:: python

Create NaiveBayes object
------------------------

.. autoclass:: NaiveBayes


   .. automethod:: __init__


Get parameters
--------------
.. automethod:: NaiveBayes.get_params

Set parameters
--------------
.. automethod:: NaiveBayes.set_params

.. rubric:: Methods

Fit and predict
===============

fit
---
.. automethod:: NaiveBayes.fit

predict
-------
.. automethod:: NaiveBayes.predict

fit_predict
-----------
.. automethod:: NaiveBayes.fit_predict

Explore result
==============

describe
--------
.. automethod:: NaiveBayes.describe

get labels
----------
.. automethod:: NaiveBayes.labels_

_retrieve_NaiveBayes_Model
--------------------------
.. automethod:: NaiveBayes._retrieve_NaiveBayes_Model